@@ -4,7 +4,7 @@
 #include "modules/packages/packages.h"
 #include "util/stringUtils.h"
 
-#define FF_PACKAGES_NUM_FORMAT_ARGS 26
+#define FF_PACKAGES_NUM_FORMAT_ARGS 29
 
 void ffPrintPackages(FFPackagesOptions* options)
 {
@@ -70,6 +70,9 @@ void ffPrintPackages(FFPackagesOptions* options)
     }
     else
     {
+        uint32_t nixAll = counts.nixDefault + counts.nixSystem + counts.nixUser;
+        uint32_t flatpakAll = counts.flatpakSystem + counts.flatpakUser;
+        uint32_t brewAll = counts.brew + counts.brewCask;
         FF_PRINT_FORMAT_CHECKED(FF_PACKAGES_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_PACKAGES_NUM_FORMAT_ARGS, ((FFformatarg[]){
             {FF_FORMAT_ARG_TYPE_UINT, &counts.all},
             {FF_FORMAT_ARG_TYPE_UINT, &counts.pacman},
@@ -97,6 +100,9 @@ void ffPrintPackages(FFPackagesOptions* options)
             {FF_FORMAT_ARG_TYPE_UINT, &counts.winget},
             {FF_FORMAT_ARG_TYPE_UINT, &counts.opkg},
             {FF_FORMAT_ARG_TYPE_UINT, &counts.am},
+            {FF_FORMAT_ARG_TYPE_UINT, &nixAll},
+            {FF_FORMAT_ARG_TYPE_UINT, &flatpakAll},
+            {FF_FORMAT_ARG_TYPE_UINT, &brewAll},
         }));
     }
 
@@ -123,33 +129,63 @@ bool ffParsePackagesCommandOptions(FFPackagesOptions* options, const char* key,
                 *end = '\0';
 
             #define FF_TEST_PACKAGE_NAME(name) else if (ffStrEqualsIgnCase(start, #name)) { options->disabled |= FF_PACKAGES_FLAG_ ## name ## _BIT; }
-            if (false);
-            FF_TEST_PACKAGE_NAME(APK)
-            FF_TEST_PACKAGE_NAME(BREW)
-            FF_TEST_PACKAGE_NAME(CHOCO)
-            FF_TEST_PACKAGE_NAME(DPKG)
-            FF_TEST_PACKAGE_NAME(EMERGE)
-            FF_TEST_PACKAGE_NAME(EOPKG)
-            FF_TEST_PACKAGE_NAME(FLATPAK)
-            FF_TEST_PACKAGE_NAME(NIX)
-            FF_TEST_PACKAGE_NAME(OPKG)
-            FF_TEST_PACKAGE_NAME(PACMAN)
-            FF_TEST_PACKAGE_NAME(PALUDIS)
-            FF_TEST_PACKAGE_NAME(PKG)
-            FF_TEST_PACKAGE_NAME(PKGTOOL)
-            FF_TEST_PACKAGE_NAME(MACPORTS)
-            FF_TEST_PACKAGE_NAME(RPM)
-            FF_TEST_PACKAGE_NAME(SCOOP)
-            FF_TEST_PACKAGE_NAME(SNAP)
-            FF_TEST_PACKAGE_NAME(WINGET)
-            FF_TEST_PACKAGE_NAME(XBPS)
-            FF_TEST_PACKAGE_NAME(AM)
+            switch (toupper(start[0]))
+            {
+                case 'A': if (false);
+                    FF_TEST_PACKAGE_NAME(APK)
+                    FF_TEST_PACKAGE_NAME(AM)
+                    break;
+                case 'B': if (false);
+                    FF_TEST_PACKAGE_NAME(BREW)
+                    break;
+                case 'C': if (false);
+                    FF_TEST_PACKAGE_NAME(CHOCO)
+                    break;
+                case 'D': if (false);
+                    FF_TEST_PACKAGE_NAME(DPKG)
+                    break;
+                case 'E': if (false);
+                    FF_TEST_PACKAGE_NAME(EMERGE)
+                    FF_TEST_PACKAGE_NAME(EOPKG)
+                    break;
+                case 'F': if (false);
+                    FF_TEST_PACKAGE_NAME(FLATPAK)
+                    break;
+                case 'M': if (false);
+                    FF_TEST_PACKAGE_NAME(MACPORTS)
+                    break;
+                case 'N': if (false);
+                    FF_TEST_PACKAGE_NAME(NIX)
+                    break;
+                case 'O': if (false);
+                    FF_TEST_PACKAGE_NAME(OPKG)
+                    break;
+                case 'P': if (false);
+                    FF_TEST_PACKAGE_NAME(PACMAN)
+                    FF_TEST_PACKAGE_NAME(PKG)
+                    FF_TEST_PACKAGE_NAME(PKGTOOL)
+                    FF_TEST_PACKAGE_NAME(PALUDIS)
+                    break;
+                case 'R': if (false);
+                    FF_TEST_PACKAGE_NAME(RPM)
+                    break;
+                case 'S': if (false);
+                    FF_TEST_PACKAGE_NAME(SCOOP)
+                    FF_TEST_PACKAGE_NAME(SNAP)
+                    break;
+                case 'W': if (false);
+                    FF_TEST_PACKAGE_NAME(WINGET)
+                    break;
+                case 'X': if (false);
+                    FF_TEST_PACKAGE_NAME(XBPS)
+                    break;
+            }
             #undef FF_TEST_PACKAGE_NAME
 
             if (end)
             {
                 start = end + 1;
-                end = strchr(end, ':');
+                end = strchr(start, ':');
             }
             else
                 break;
@@ -193,29 +229,60 @@ void ffParsePackagesJsonObject(FFPackagesOptions* options, yyjson_val* module)
                     const char* flag = yyjson_get_str(flagObj);
 
                     #define FF_TEST_PACKAGE_NAME(name) else if (ffStrEqualsIgnCase(flag, #name)) { options->disabled |= FF_PACKAGES_FLAG_ ## name ## _BIT; }
-                    if (false);
-                    FF_TEST_PACKAGE_NAME(APK)
-                    FF_TEST_PACKAGE_NAME(BREW)
-                    FF_TEST_PACKAGE_NAME(CHOCO)
-                    FF_TEST_PACKAGE_NAME(DPKG)
-                    FF_TEST_PACKAGE_NAME(EMERGE)
-                    FF_TEST_PACKAGE_NAME(EOPKG)
-                    FF_TEST_PACKAGE_NAME(FLATPAK)
-                    FF_TEST_PACKAGE_NAME(NIX)
-                    FF_TEST_PACKAGE_NAME(OPKG)
-                    FF_TEST_PACKAGE_NAME(PACMAN)
-                    FF_TEST_PACKAGE_NAME(PALUDIS)
-                    FF_TEST_PACKAGE_NAME(PKG)
-                    FF_TEST_PACKAGE_NAME(PKGTOOL)
-                    FF_TEST_PACKAGE_NAME(MACPORTS)
-                    FF_TEST_PACKAGE_NAME(RPM)
-                    FF_TEST_PACKAGE_NAME(SCOOP)
-                    FF_TEST_PACKAGE_NAME(SNAP)
-                    FF_TEST_PACKAGE_NAME(WINGET)
-                    FF_TEST_PACKAGE_NAME(XBPS)
-                    FF_TEST_PACKAGE_NAME(AM)
+                    switch (toupper(flag[0]))
+                    {
+                        case 'A': if (false);
+                            FF_TEST_PACKAGE_NAME(APK)
+                            FF_TEST_PACKAGE_NAME(AM)
+                            break;
+                        case 'B': if (false);
+                            FF_TEST_PACKAGE_NAME(BREW)
+                            break;
+                        case 'C': if (false);
+                            FF_TEST_PACKAGE_NAME(CHOCO)
+                            break;
+                        case 'D': if (false);
+                            FF_TEST_PACKAGE_NAME(DPKG)
+                            break;
+                        case 'E': if (false);
+                            FF_TEST_PACKAGE_NAME(EMERGE)
+                            FF_TEST_PACKAGE_NAME(EOPKG)
+                            break;
+                        case 'F': if (false);
+                            FF_TEST_PACKAGE_NAME(FLATPAK)
+                            break;
+                        case 'M': if (false);
+                            FF_TEST_PACKAGE_NAME(MACPORTS)
+                            break;
+                        case 'N': if (false);
+                            FF_TEST_PACKAGE_NAME(NIX)
+                            break;
+                        case 'O': if (false);
+                            FF_TEST_PACKAGE_NAME(OPKG)
+                            break;
+                        case 'P': if (false);
+                            FF_TEST_PACKAGE_NAME(PACMAN)
+                            FF_TEST_PACKAGE_NAME(PKG)
+                            FF_TEST_PACKAGE_NAME(PKGTOOL)
+                            FF_TEST_PACKAGE_NAME(PALUDIS)
+                            break;
+                        case 'R': if (false);
+                            FF_TEST_PACKAGE_NAME(RPM)
+                            break;
+                        case 'S': if (false);
+                            FF_TEST_PACKAGE_NAME(SCOOP)
+                            FF_TEST_PACKAGE_NAME(SNAP)
+                            break;
+                        case 'W': if (false);
+                            FF_TEST_PACKAGE_NAME(WINGET)
+                            break;
+                        case 'X': if (false);
+                            FF_TEST_PACKAGE_NAME(XBPS)
+                            break;
+                    }
                     #undef FF_TEST_PACKAGE_NAME
                 }
+                continue;
             }
         }
 
@@ -306,7 +373,7 @@ void ffGeneratePackagesJsonResult(FF_MAYBE_UNUSED FFPackagesOptions* options, yy
 
 void ffPrintPackagesHelpFormat(void)
 {
-    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_PACKAGES_MODULE_NAME, "{2} (pacman){?3}[{3}]{?}, {4} (dpkg), {5} (rpm), {6} (emerge), {7} (eopkg), {8} (xbps), {9} (nix-system), {10} (nix-user), {11} (nix-default), {12} (apk), {13} (pkg), {14} (flatpak-system), {15} (flatpack-user), {16} (snap), {17} (brew), {18} (brew-cask), {19} (MacPorts), {20} (scoop), {21} (choco), {22} (pkgtool), {23} (paludis), {24} (winget), {25} (opkg)", FF_PACKAGES_NUM_FORMAT_ARGS, ((const char* []) {
+    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_PACKAGES_MODULE_NAME, "{2} (pacman){?3}[{3}]{?}, {4} (dpkg), {5} (rpm), {6} (emerge), {7} (eopkg), {8} (xbps), {9} (nix-system), {10} (nix-user), {11} (nix-default), {12} (apk), {13} (pkg), {14} (flatpak-system), {15} (flatpack-user), {16} (snap), {17} (brew), {18} (brew-cask), {19} (MacPorts), {20} (scoop), {21} (choco), {22} (pkgtool), {23} (paludis), {24} (winget), {25} (opkg), {26} (am)", FF_PACKAGES_NUM_FORMAT_ARGS, ((const char* []) {
         "Number of all packages",
         "Number of pacman packages",
         "Pacman branch on manjaro",
@@ -333,6 +400,9 @@ void ffPrintPackagesHelpFormat(void)
         "Number of winget packages",
         "Number of opkg packages",
         "Number of am packages",
+        "Total number of all nix packages",
+        "Total number of all flatpak packages",
+        "Total number of all brew packages",
     }));
 }
 
