@@ -94,20 +94,46 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
             yyjson_val* ndigits = yyjson_obj_get(val, "ndigits");
             if (ndigits) options->percentNdigits = (uint8_t) yyjson_get_uint(ndigits);
         }
-        else if (ffStrEqualsIgnCase(key, "temperatureUnit"))
+        else if (ffStrEqualsIgnCase(key, "temp"))
         {
-            int value;
-            const char* error = ffJsonConfigParseEnum(val, &value, (FFKeyValuePair[]) {
-                { "CELSIUS", FF_TEMPERATURE_UNIT_CELSIUS },
-                { "C", FF_TEMPERATURE_UNIT_CELSIUS },
-                { "FAHRENHEIT", FF_TEMPERATURE_UNIT_FAHRENHEIT },
-                { "F", FF_TEMPERATURE_UNIT_FAHRENHEIT },
-                { "KELVIN", FF_TEMPERATURE_UNIT_KELVIN },
-                { "K", FF_TEMPERATURE_UNIT_KELVIN },
-                {},
-            });
-            if (error) return error;
-            options->temperatureUnit = (FFTemperatureUnit) value;
+            if (!yyjson_is_obj(val))
+                return "display.temp must be an object";
+
+            yyjson_val* unit = yyjson_obj_get(val, "unit");
+            if (unit)
+            {
+                int value;
+                const char* error = ffJsonConfigParseEnum(unit, &value, (FFKeyValuePair[]) {
+                    { "CELSIUS", FF_TEMPERATURE_UNIT_CELSIUS },
+                    { "C", FF_TEMPERATURE_UNIT_CELSIUS },
+                    { "FAHRENHEIT", FF_TEMPERATURE_UNIT_FAHRENHEIT },
+                    { "F", FF_TEMPERATURE_UNIT_FAHRENHEIT },
+                    { "KELVIN", FF_TEMPERATURE_UNIT_KELVIN },
+                    { "K", FF_TEMPERATURE_UNIT_KELVIN },
+                    {},
+                });
+                if (error) return error;
+                options->temperatureUnit = (FFTemperatureUnit) value;
+            }
+
+            yyjson_val* ndigits = yyjson_obj_get(val, "ndigits");
+            if (ndigits) options->tempNdigits = (uint8_t) yyjson_get_uint(ndigits);
+
+            yyjson_val* color = yyjson_obj_get(val, "color");
+            if (color)
+            {
+                if (!yyjson_is_obj(color))
+                    return "display.temperature.color must be an object";
+
+                yyjson_val* green = yyjson_obj_get(color, "green");
+                if (green) ffOptionParseColor(yyjson_get_str(green), &options->tempColorGreen);
+
+                yyjson_val* yellow = yyjson_obj_get(color, "yellow");
+                if (yellow) ffOptionParseColor(yyjson_get_str(yellow), &options->tempColorYellow);
+
+                yyjson_val* red = yyjson_obj_get(color, "red");
+                if (red) ffOptionParseColor(yyjson_get_str(red), &options->tempColorRed);
+            }
         }
         else if (ffStrEqualsIgnCase(key, "percent"))
         {
@@ -163,10 +189,8 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
             options->noBuffer = yyjson_get_bool(val);
         else if (ffStrEqualsIgnCase(key, "keyWidth"))
             options->keyWidth = (uint32_t) yyjson_get_uint(val);
-        else if (ffStrStartsWithIgnCase(key, "percent"))
-            return "Property `display.percentX` has been changed to `display.percent.x`";
-        else if (ffStrStartsWithIgnCase(key, "size"))
-            return "Property `display.sizeX` has been changed to `display.size.x`";
+        else if (ffStrEqualsIgnCase(key, "tsVersion"))
+            options->tsVersion = yyjson_get_bool(val);
         else
             return "Unknown display property";
     }
@@ -253,17 +277,31 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
             {}
         });
     }
-    else if(ffStrEqualsIgnCase(key, "--temperature-unit"))
+    else if(ffStrStartsWithIgnCase(key, "--temperature-"))
     {
-        options->temperatureUnit = (FFTemperatureUnit) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
-            { "CELSIUS", FF_TEMPERATURE_UNIT_CELSIUS },
-            { "C", FF_TEMPERATURE_UNIT_CELSIUS },
-            { "FAHRENHEIT", FF_TEMPERATURE_UNIT_FAHRENHEIT },
-            { "F", FF_TEMPERATURE_UNIT_FAHRENHEIT },
-            { "KELVIN", FF_TEMPERATURE_UNIT_KELVIN },
-            { "K", FF_TEMPERATURE_UNIT_KELVIN },
-            {},
-        });
+        const char* subkey = key + strlen("--temperature-");
+        if(ffStrEqualsIgnCase(subkey, "unit"))
+        {
+            options->temperatureUnit = (FFTemperatureUnit) ffOptionParseEnum(key, value, (FFKeyValuePair[]) {
+                { "CELSIUS", FF_TEMPERATURE_UNIT_CELSIUS },
+                { "C", FF_TEMPERATURE_UNIT_CELSIUS },
+                { "FAHRENHEIT", FF_TEMPERATURE_UNIT_FAHRENHEIT },
+                { "F", FF_TEMPERATURE_UNIT_FAHRENHEIT },
+                { "KELVIN", FF_TEMPERATURE_UNIT_KELVIN },
+                { "K", FF_TEMPERATURE_UNIT_KELVIN },
+                {},
+            });
+        }
+        else if (ffStrEqualsIgnCase(subkey, "ndigits"))
+            options->tempNdigits = (uint8_t) ffOptionParseUInt32(key, value);
+        else if(ffStrEqualsIgnCase(subkey, "color-green"))
+            ffOptionParseColor(value, &options->tempColorGreen);
+        else if(ffStrEqualsIgnCase(subkey, "color-yellow"))
+            ffOptionParseColor(value, &options->tempColorYellow);
+        else if(ffStrEqualsIgnCase(subkey, "color-red"))
+            ffOptionParseColor(value, &options->tempColorRed);
+        else
+            return false;
     }
     else if(ffStrStartsWithIgnCase(key, "--percent-"))
     {
@@ -297,6 +335,8 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
         else
             return false;
     }
+    else if(ffStrEqualsIgnCase(key, "--ts-version"))
+        options->tsVersion = ffOptionParseBoolean(value);
     else
         return false;
     return true;
@@ -314,20 +354,24 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
 
     #ifdef NDEBUG
     options->disableLinewrap = !options->pipe;
-    options->hideCursor = !options->pipe;
     #else
     options->disableLinewrap = false;
-    options->hideCursor = false;
     #endif
 
+    options->hideCursor = false;
     options->binaryPrefixType = FF_BINARY_PREFIX_TYPE_IEC;
     options->sizeNdigits = 2;
     options->sizeMaxPrefix = UINT8_MAX;
-    options->temperatureUnit = FF_TEMPERATURE_UNIT_CELSIUS;
     options->stat = false;
     options->noBuffer = false;
     options->keyWidth = 0;
 
+    options->temperatureUnit = FF_TEMPERATURE_UNIT_CELSIUS;
+    options->tempNdigits = 1;
+    ffStrbufInitStatic(&options->tempColorGreen, FF_COLOR_FG_GREEN);
+    ffStrbufInitStatic(&options->tempColorYellow, FF_COLOR_FG_LIGHT_YELLOW);
+    ffStrbufInitStatic(&options->tempColorRed, FF_COLOR_FG_LIGHT_RED);
+
     ffStrbufInitStatic(&options->barCharElapsed, "■");
     ffStrbufInitStatic(&options->barCharTotal, "-");
     options->barWidth = 10;
@@ -337,6 +381,8 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     ffStrbufInitStatic(&options->percentColorGreen, FF_COLOR_FG_GREEN);
     ffStrbufInitStatic(&options->percentColorYellow, FF_COLOR_FG_LIGHT_YELLOW);
     ffStrbufInitStatic(&options->percentColorRed, FF_COLOR_FG_LIGHT_RED);
+
+    options->tsVersion = true;
 }
 
 void ffOptionsDestroyDisplay(FFOptionsDisplay* options)
@@ -430,20 +476,38 @@ void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_do
             yyjson_mut_obj_add_val(doc, obj, "size", size);
     }
 
-    if (options->temperatureUnit != defaultOptions.temperatureUnit)
     {
-        switch (options->temperatureUnit)
+        yyjson_mut_val* temperature = yyjson_mut_obj(doc);
+        if (options->temperatureUnit != defaultOptions.temperatureUnit)
         {
-            case FF_TEMPERATURE_UNIT_CELSIUS:
-                yyjson_mut_obj_add_str(doc, obj, "temperatureUnit", "C");
-                break;
-            case FF_TEMPERATURE_UNIT_FAHRENHEIT:
-                yyjson_mut_obj_add_str(doc, obj, "temperatureUnit", "F");
-                break;
-            case FF_TEMPERATURE_UNIT_KELVIN:
-                yyjson_mut_obj_add_str(doc, obj, "temperatureUnit", "K");
-                break;
+            switch (options->temperatureUnit)
+            {
+                case FF_TEMPERATURE_UNIT_CELSIUS:
+                    yyjson_mut_obj_add_str(doc, obj, "unit", "C");
+                    break;
+                case FF_TEMPERATURE_UNIT_FAHRENHEIT:
+                    yyjson_mut_obj_add_str(doc, obj, "unit", "F");
+                    break;
+                case FF_TEMPERATURE_UNIT_KELVIN:
+                    yyjson_mut_obj_add_str(doc, obj, "unit", "K");
+                    break;
+            }
         }
+        if (options->tempNdigits != defaultOptions.tempNdigits)
+            yyjson_mut_obj_add_uint(doc, temperature, "ndigits", options->tempNdigits);
+        {
+            yyjson_mut_val* color = yyjson_mut_obj(doc);
+            if (!ffStrbufEqual(&options->tempColorGreen, &defaultOptions.tempColorGreen))
+                yyjson_mut_obj_add_strbuf(doc, color, "green", &options->tempColorGreen);
+            if (!ffStrbufEqual(&options->tempColorYellow, &defaultOptions.tempColorYellow))
+                yyjson_mut_obj_add_strbuf(doc, color, "yellow", &options->tempColorYellow);
+            if (!ffStrbufEqual(&options->tempColorRed, &defaultOptions.tempColorRed))
+                yyjson_mut_obj_add_strbuf(doc, color, "red", &options->tempColorRed);
+            if (yyjson_mut_obj_size(color) > 0)
+                yyjson_mut_obj_add_val(doc, temperature, "color", color);
+        }
+        if (yyjson_mut_obj_size(temperature) > 0)
+            yyjson_mut_obj_add_val(doc, obj, "temp", temperature);
     }
 
     {
@@ -452,6 +516,17 @@ void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_do
             yyjson_mut_obj_add_uint(doc, percent, "type", options->percentType);
         if (options->percentNdigits != defaultOptions.percentNdigits)
             yyjson_mut_obj_add_uint(doc, percent, "ndigits", options->percentNdigits);
+        {
+            yyjson_mut_val* color = yyjson_mut_obj(doc);
+            if (!ffStrbufEqual(&options->percentColorGreen, &defaultOptions.percentColorGreen))
+                yyjson_mut_obj_add_strbuf(doc, color, "green", &options->percentColorGreen);
+            if (!ffStrbufEqual(&options->percentColorYellow, &defaultOptions.percentColorYellow))
+                yyjson_mut_obj_add_strbuf(doc, color, "yellow", &options->percentColorYellow);
+            if (!ffStrbufEqual(&options->percentColorRed, &defaultOptions.percentColorRed))
+                yyjson_mut_obj_add_strbuf(doc, color, "red", &options->percentColorRed);
+            if (yyjson_mut_obj_size(color) > 0)
+                yyjson_mut_obj_add_val(doc, percent, "color", color);
+        }
         if (yyjson_mut_obj_size(percent) > 0)
             yyjson_mut_obj_add_val(doc, obj, "percent", percent);
     }
